is_as_ptr

Function is_as_ptr 

pub fn is_as_ptr(callee: Option<DefId>) -> bool
Whether callee produces a raw pointer (or NonNull) alias of its first argument: as_ptr/as_mut_ptr, into_raw, and pointer cast (incl. cast_mut/cast_const). as_ptr_range/as_mut_ptr_range are excluded because they return a Range of two pointers rather than a single pointer; NonNull::new_unchecked/as_ref/as_mut are excluded because they do not produce a raw pointer (and new_unchecked must not mark its result non-null, or it would hide new_unchecked(null) unsoundness).